% Auto-generated chapter 4 for tirmidhi
% Hadiths in this chapter: 42

\hadithdefcmd{tirmidhi}{488}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ يَوْمٍ طَلَعَتْ فِيهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُدْخِلَ الْجَنَّةَ وَفِيهِ أُخْرِجَ مِنْهَا وَلاَ تَقُومُ السَّاعَةُ إِلاَّ فِي يَوْمِ الْجُمُعَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي لُبَابَةَ وَسَلْمَانَ وَأَبِي ذَرٍّ وَسَعْدِ بْنِ عُبَادَةَ وَأَوْسِ بْنِ أَوْسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{488}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that:the Prophet said: "The best day that the sun has risen upon is Friday. On it Adam was created, on it he entered Paradise, and on it, he was expelled from it. And the Hour will not be established except on Friday}}
\hadithdefcmd{tirmidhi}{489}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْهَاشِمِيُّ الْبَصْرِيُّ الْعَطَّارُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ الْحَنَفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حُمَيْدٍ، حَدَّثَنَا مُوسَى بْنُ وَرْدَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْتَمِسُوا السَّاعَةَ الَّتِي تُرْجَى فِي يَوْمِ الْجُمُعَةِ بَعْدَ الْعَصْرِ إِلَى غَيْبُوبَةِ الشَّمْسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَمُحَمَّدُ بْنُ أَبِي حُمَيْدٍ يُضَعَّفُ ضَعَّفَهُ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ وَيُقَالُ لَهُ حَمَّادُ بْنُ أَبِي حُمَيْدٍ وَيُقَالُ هُوَ أَبُو إِبْرَاهِيمَ الأَنْصَارِيُّ وَهُوَ مُنْكَرُ الْحَدِيثِ ‏.‏ وَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ السَّاعَةَ الَّتِي تُرْجَى فِيهَا بَعْدَ الْعَصْرِ إِلَى أَنْ تَغْرُبَ الشَّمْسُ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ أَحْمَدُ أَكْثَرُ الأَحَادِيثِ فِي السَّاعَةِ الَّتِي تُرْجَى فِيهَا إِجَابَةُ الدَّعْوَةِ أَنَّهَا بَعْدَ صَلاَةِ الْعَصْرِ وَتُرْجَى بَعْدَ زَوَالِ الشَّمْسِ ‏.‏\hadithno{489}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that :the Prophet said: "Seek out the hour that is hoped for on Friday after Asr until the sun has set}}
\hadithdefcmd{tirmidhi}{490}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجُمُعَةِ سَاعَةً لاَ يَسْأَلُ اللَّهَ الْعَبْدُ فِيهَا شَيْئًا إِلاَّ آتَاهُ اللَّهُ إِيَّاهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَيَّةُ سَاعَةٍ هِيَ قَالَ ‏"‏ حِينَ تُقَامُ الصَّلاَةُ إِلَى الاِنْصِرَافِ مِنْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَأَبِي ذَرٍّ وَسَلْمَانَ وَعَبْدِ اللَّهِ بْنِ سَلاَمٍ وَأَبِي لُبَابَةَ وَسَعْدِ بْنِ عُبَادَةَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَمْرِو بْنِ عَوْفٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{490}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin Abdullah bin Amr bin Awf Al-Muzani narrated from his father, from his grandfather, that :the Prophet said: "On Friday there is an hour in which the worshipper does not ask Allah for anything except that Allah grants it to him." They said: "O Messenger of Allah! Which hour is it?" He said: "When the prayer is begun until it is finished}}
\hadithdefcmd{tirmidhi}{491}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ يَوْمٍ طَلَعَتْ فِيهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُدْخِلَ الْجَنَّةَ وَفِيهِ أُهْبِطَ مِنْهَا وَفِيهِ سَاعَةٌ لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ يُصَلِّي فَيَسْأَلُ اللَّهَ فِيهَا شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَلَقِيتُ عَبْدَ اللَّهِ بْنَ سَلاَمٍ فَذَكَرْتُ لَهُ هَذَا الْحَدِيثَ فَقَالَ أَنَا أَعْلَمُ بِتِلْكَ السَّاعَةِ ‏.‏ فَقُلْتُ أَخْبِرْنِي بِهَا وَلاَ تَضْنَنْ بِهَا عَلَىَّ قَالَ هِيَ بَعْدَ الْعَصْرِ إِلَى أَنْ تَغْرُبَ الشَّمْسُ ‏.‏ فَقُلْتُ كَيْفَ تَكُونُ بَعْدَ الْعَصْرِ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يُوَافِقُهَا عَبْدٌ مَسْلِمٌ وَهُوَ يُصَلِّي ‏"‏ ‏.‏ وَتِلْكَ السَّاعَةُ لاَ يُصَلَّى فِيهَا فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَلَسَ مَجْلِسًا يَنْتَظِرُ الصَّلاَةَ فَهُوَ فِي صَلاَةٍ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ فَهُوَ ذَاكَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَمَعْنَى قَوْلِهِ ‏"‏ أَخْبِرْنِي بِهَا وَلاَ تَضْنَنْ بِهَا عَلَىَّ ‏"‏ ‏.‏ لاَ تَبْخَلْ بِهَا عَلَىَّ وَالضَّنُّ الْبُخْلُ وَالظَّنِينُ الْمُتَّهَمُ ‏.‏\hadithno{491}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"Allah's Messenger said: The best day that the sun has risen upon is Friday. On it Adam was created, on it he entered Paradise, and on it, he was sent down from it. And in it there is an hour in which the Muslim worshipper would not stand in Salat, asking Allah for anything except that He would give it to him.'" Abu Hurairah said: "I met Abdullah bin Salam, and I mentioned this Hadith to him. He said: 'I am more knowledgeable about that hour.' So I said: 'Inform me about it, and do not keep any of it from me.' He said: 'It is after al-Asr until the sun has set.' I said: 'How can it be after Al-Asr when Allah's Messenger said: ' the Muslim worshipper would not stand in Salat.' And that is a time that prayer is not performed in?" So Abdullah bin Salam said: 'Didn't Allah's Messenger say: "Whoever sat in a gathering awaiting the Salat then he is in Salat"? I said: 'Of course.' He said: 'Then that is it}}
\hadithdefcmd{tirmidhi}{492}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَتَى الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي سَعِيدٍ وَجَابِرٍ وَالْبَرَاءِ وَعَائِشَةَ وَأَبِي الدَّرْدَاءِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{492}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim narrated from his father, from his grandfather, that he heard :the Prophet saying: "Whoever comes on Friday, then let him perform Ghusl}}
\hadithdefcmd{tirmidhi}{493}{وَرُوِيَ عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثُ أَيْضًا ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ عَنِ ابْنِ شِهَابٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ أَبِيهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ وَقَالَ مُحَمَّدٌ وَحَدِيثُ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ كِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏ وَقَالَ بَعْضُ أَصْحَابِ الزُّهْرِيِّ عَنِ الزُّهْرِيِّ قَالَ حَدَّثَنِي آلُ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{493}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Salim narrated:(Another chain) from Abdullah bin Umar from the Prophet which is similar}}
\hadithdefcmd{tirmidhi}{494}{قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْغُسْلِ يَوْمَ الْجُمُعَةِ أَيْضًا وَهُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ رَوَاهُ يُونُسُ وَمَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ بَيْنَمَا عُمَرُ بْنُ الْخَطَّابِ يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ دَخَلَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ أَيَّةُ سَاعَةٍ هَذِهِ فَقَالَ مَا هُوَ إِلاَّ أَنْ سَمِعْتُ النِّدَاءَ وَمَا زِدْتُ عَلَى أَنْ تَوَضَّأْتُ ‏.‏ قَالَ وَالْوُضُوءَ أَيْضًا وَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِالْغُسْلِ ‏.‏ حَدَّثَنَا بِذَلِكَ أَبُو بَكْرٍ مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{494}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{And Yunus and Ma'mar reported, from Az-Zuhri, from Salim Wudu from his father:"Umar bin Al-Khattab was giving a Khutbah on Friday when a man from the Companions of the Prophet entered. So he said: "What time is it?" So he said: 'I don't know, I heard the call and did nothing more than perform Wudu.' So he said: And Wudu again!? I know surely that the Messenger of Allah has ordered Ghusl}}
\hadithdefcmd{tirmidhi}{495}{قَالَ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا أَبُو صَالِحٍ عَبْدُ اللَّهِ بْنُ صَالِحٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، بِهَذَا الْحَدِيثِ ‏.‏ وَرَوَى مَالِكٌ، هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، قَالَ بَيْنَمَا عُمَرُ بْنُ الْخَطَّابِ يَخْطُبُ يَوْمَ الْجُمُعَةِ ‏.‏ فَذَكَرَ هَذَا الْحَدِيثَ ‏.‏ قَالَ أَبُو عِيسَى وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَقَالَ الصَّحِيحُ حَدِيثُ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ رُوِيَ عَنْ مَالِكٍ أَيْضًا عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ نَحْوُ هَذَا الْحَدِيثِ ‏.‏\hadithno{495}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{(Another chain reaching to Az-Zuhri) with this Hadith.Malik reported this Hadith from Az-Zuhri, from Salim who said:"Umar [bin al-Khattab] was giving a Khutbah on Friday." And he mentioned this Hadith}}
\hadithdefcmd{tirmidhi}{496}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، وَأَبُو جَنَابٍ يَحْيَى بْنُ أَبِي حَيَّةَ عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ يَحْيَى بْنِ الْحَارِثِ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ وَغَسَّلَ وَبَكَّرَ وَابْتَكَرَ وَدَنَا وَاسْتَمَعَ وَأَنْصَتَ كَانَ لَهُ بِكُلِّ خَطْوَةٍ يَخْطُوهَا أَجْرُ سَنَةٍ صِيَامُهَا وَقِيَامُهَا ‏"‏ ‏.‏ قَالَ مَحْمُودٌ قَالَ وَكِيعٌ اغْتَسَلَ هُوَ وَغَسَّلَ امْرَأَتَهُ ‏.‏ قَالَ وَيُرْوَى عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ قَالَ فِي هَذَا الْحَدِيثِ ‏"‏ مَنْ غَسَّلَ وَاغْتَسَلَ ‏"‏ ‏.‏ يَعْنِي غَسَلَ رَأْسَهُ وَاغْتَسَلَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَعِمْرَانَ بْنِ حُصَيْنٍ وَسَلْمَانَ وَأَبِي ذَرٍّ وَأَبِي سَعِيدٍ وَابْنِ عُمَرَ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَوْسِ بْنِ أَوْسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو الأَشْعَثِ الصَّنْعَانِيُّ اسْمُهُ شَرَاحِيلُ بْنُ آدَةَ ‏.‏ وَأَبُو جَنَابٍ يَحْيَى بْنُ حَبِيبٍ الْقَصَّابُ الْكُوفِيُّ ‏.‏\hadithno{496}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aws bin Aws narrated:"Allah's Messenger said to me: 'Whoever performs Ghusl on Friday, and bathes completely, and goes early, arriving early, gets close and listens and is silent, there will be for him in every step he take the reward of a year of fasting and standing (in prayer)}}
\hadithdefcmd{tirmidhi}{497}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا سَعِيدُ بْنُ سُفْيَانَ الْجَحْدَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ يَوْمَ الْجُمُعَةِ فَبِهَا وَنِعْمَتْ وَمَنِ اغْتَسَلَ فَالْغُسْلُ أَفْضَلُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُ أَصْحَابِ قَتَادَةَ عَنْ قَتَادَةَ عَنِ الْحَسَنِ عَنْ سَمُرَةَ بْنِ جُنْدَبٍ وَرَوَاهُ بَعْضُهُمْ عَنْ قَتَادَةَ عَنِ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمُ اخْتَارُوا الْغُسْلَ يَوْمَ الْجُمُعَةِ وَرَأَوْا أَنْ يُجْزِئَ الْوُضُوءُ مِنَ الْغُسْلِ يَوْمَ الْجُمُعَةِ ‏.‏ قَالَ الشَّافِعِيُّ وَمِمَّا يَدُلُّ عَلَى أَنَّ أَمْرَ النَّبِيِّ صلى الله عليه وسلم بِالْغُسْلِ يَوْمَ الْجُمُعَةِ أَنَّهُ عَلَى الاِخْتِيَارِ لاَ عَلَى الْوُجُوبِ حَدِيثُ عُمَرَ حَيْثُ قَالَ لِعُثْمَانَ وَالْوُضُوءَ أَيْضًا وَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِالْغُسْلِ يَوْمَ الْجُمُعَةِ ‏.‏ فَلَوْ عَلِمَا أَنَّ أَمْرَهُ عَلَى الْوُجُوبِ لاَ عَلَى الاِخْتِيَارِ لَمْ يَتْرُكْ عُمَرُ عُثْمَانَ حَتَّى يَرُدَّهُ وَيَقُولَ لَهُ ارْجِعْ فَاغْتَسِلْ وَلَمَا خَفِيَ عَلَى عُثْمَانَ ذَلِكَ مَعَ عِلْمِهِ وَلَكِنْ دَلَّ فِي هَذَا الْحَدِيثِ أَنَّ الْغُسْلَ يَوْمَ الْجُمُعَةِ فِيهِ فَضْلٌ مِنْ غَيْرِ وُجُوبٍ يَجِبُ عَلَى الْمَرْءِ فِي ذَلِكَ ‏.‏\hadithno{497}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Samurah bin Jundah narrated that :Allah's Messenger said: "Whoever performs Wudu on Friday, then he will receive the blessing, and whoever performs Ghusl then Ghusl is more virtuous}}
\hadithdefcmd{tirmidhi}{498}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ أَتَى الْجُمُعَةَ فَدَنَا وَاسْتَمَعَ وَأَنْصَتَ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ وَزِيَادَةُ ثَلاَثَةِ أَيَّامٍ وَمَنْ مَسَّ الْحَصَى فَقَدْ لَغَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{498}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairh narrated that :Allah's Messenger said: "Whoever performs Wudu, performing his Wudu well, then he comes to the Friday (prayer), and he gets close, listens and is silent, then whatever (sin) was between that and (the last) Friday are forgiven for him, in addition to three days. And whoever touches the pebbles, he has committed Lagha (useless activity)}}
\hadithdefcmd{tirmidhi}{499}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فَكَأَنَّمَا قَرَّبَ بَدَنَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا أَقْرَنَ وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{499}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Whoever performs Ghusl on Friday - the Ghusl for Janabah - then he goes, he is like one who gave a camel in charity. Whoever goes in the second hour then he is like one who gave a cow in charity. Whoever goes in the third hour then he is like the one who have a ram in charity. Whoever goes in the fourth hour then he is like the one who gave a chicken in charity. Whoever goes in the fifth hour, then he is like one who gave an egg in charity. When the Imam comes out, the angels are present listening to the remembrance}}
\hadithdefcmd{tirmidhi}{500}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ عَبِيدَةَ بْنِ سُفْيَانَ، عَنْ أَبِي الْجَعْدِ يَعْنِي الضَّمْرِيَّ، وَكَانَتْ، لَهُ صُحْبَةٌ فِيمَا زَعَمَ مُحَمَّدُ بْنُ عَمْرٍو قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ الْجُمُعَةَ ثَلاَثَ مَرَّاتٍ تَهَاوُنًا بِهَا طَبَعَ اللَّهُ عَلَى قَلْبِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي الْجَعْدِ حَدِيثٌ حَسَنٌ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنِ اسْمِ أَبِي الْجَعْدِ الضَّمْرِيِّ فَلَمْ يَعْرِفِ اسْمَهُ وَقَالَ لاَ أَعْرِفُ لَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ هَذَا الْحَدِيثَ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ عَمْرٍو ‏.‏\hadithno{500}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Al-Ja'd - meaning Ad-Damri - narrated, and he was a Companion according to the claim of Muhammad bin Amr:"Allah's Messenger said: 'Whoever neglects the Friday prayer three times (in a row) without an excuse, then Allah sets a seal upon his heart}}
\hadithdefcmd{tirmidhi}{501}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَمُحَمَّدُ بْنُ مَدُّويَهْ، قَالاَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ ثُوَيْرٍ، عَنْ رَجُلٍ، مِنْ أَهْلِ قُبَاءَ عَنْ أَبِيهِ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم - قَالَ أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نَشْهَدَ الْجُمُعَةَ مِنْ قُبَاءَ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا وَلاَ يَصِحُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلاَ يَصِحُّ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْءٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْجُمُعَةُ عَلَى مَنْ آوَاهُ اللَّيْلُ إِلَى أَهْلِهِ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ إِسْنَادُهُ ضَعِيفٌ إِنَّمَا يُرْوَى مِنْ حَدِيثِ مُعَارِكِ بْنِ عَبَّادٍ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ الْمَقْبُرِيِّ ‏.‏ وَضَعَّفَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ عَبْدَ اللَّهِ بْنَ سَعِيدٍ الْمَقْبُرِيَّ فِي الْحَدِيثِ ‏.‏ قَالَ وَاخْتَلَفَ أَهْلُ الْعِلْمِ عَلَى مَنْ تَجِبُ الْجُمُعَةُ فَقَالَ بَعْضُهُمْ تَجِبُ الْجُمُعَةُ عَلَى مَنْ آوَاهُ اللَّيْلُ إِلَى مَنْزِلِهِ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَجِبُ الْجُمُعَةُ إِلاَّ عَلَى مَنْ سَمِعَ النِّدَاءَ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{501}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Thuwair narrated from a man among the people of Quba, from his father, who was one of the Companions of the Prophet, that :he said: "The Prophet ordered us to attend the Friday prayer in Quba}}
\hadithdefcmd{tirmidhi}{502}{سَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ، يَقُولُ كُنَّا عِنْدَ أَحْمَدَ بْنِ حَنْبَلٍ فَذَكَرُوا عَلَى مَنْ تَجِبُ الْجُمُعَةُ فَلَمْ يَذْكُرْ أَحْمَدُ فِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْئًا ‏.‏ قَالَ أَحْمَدُ بْنُ الْحَسَنِ فَقُلْتُ لأَحْمَدَ بْنِ حَنْبَلٍ فِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَقَالَ أَحْمَدُ عَنِ النَّبِيِّ صلى الله عليه وسلم قُلْتُ نَعَمْ ‏.‏ قَالَ أَحْمَدُ بْنُ الْحَسَنِ حَدَّثَنَا حَجَّاجُ بْنُ نُصَيْرٍ حَدَّثَنَا مُعَارِكُ بْنُ عَبَّادٍ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْجُمُعَةُ عَلَى مَنْ آوَاهُ اللَّيْلُ إِلَى أَهْلِهِ ‏"‏ ‏.‏ قَالَ فَغَضِبَ عَلَىَّ أَحْمَدُ بْنُ حَنْبَلٍ وَقَالَ لِي اسْتَغْفِرْ رَبَّكَ اسْتَغْفِرْ رَبَّكَ ‏.‏ قَالَ أَبُو عِيسَى إِنَّمَا فَعَلَ أَحْمَدُ بْنُ حَنْبَلٍ هَذَا لأَنَّهُ لَمْ يَعُدَّ هَذَا الْحَدِيثَ شَيْئًا وَضَعَّفَهُ لِحَالِ إِسْنَادِهِ ‏.‏\hadithno{502}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrator not mentioned:I heard Ahmad bin Husain saying: "We were with Ahmad bin Hanbal, so they mentioned the one upon whom the Friday prayer is obligatory. Ahmad did not mention anything about it from the Prophet." Ahmad bin Al-Hasan said: "I said to Ahmad bin Hanbal: 'There is something about it from Abu Hurairah, from the Prophet.' So Ahmad bin Hanbal said: 'From the Prophet?' I said: 'Yes.'" [Ahmed bin Hanbal said:] "Hajjaj bin Nusair narrated to us; Mubarik bin Abbad narrated to us from Abdullah bin Sa'eed Al-Maqburi, from his father, from Abu Hurairah that the Prophet said: "The Friday prayer is required from whomever can return to his family by the night." He said: "So Ahmad [bin Hanbal] became angry with me, and he said to me: 'Seek forgiveness from your Lord, seek forgiveness from your Lord}}
\hadithdefcmd{tirmidhi}{503}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي الْجُمُعَةَ حِينَ تَمِيلُ الشَّمْسُ ‏.‏\hadithno{503}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Malik narrated:"The Prophet would pray the Friday prayer when the sun was declining}}
\hadithdefcmd{tirmidhi}{504}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ وَجَابِرٍ وَالزُّبَيْرِ بْنِ الْعَوَّامِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي أَجْمَعَ عَلَيْهِ أَكْثَرُ أَهْلِ الْعِلْمِ أَنَّ وَقْتَ الْجُمُعَةِ إِذَا زَالَتِ الشَّمْسُ كَوَقْتِ الظُّهْرِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرَأَى بَعْضُهُمْ أَنَّ صَلاَةَ الْجُمُعَةِ إِذَا صُلِّيَتْ قَبْلَ الزَّوَالِ أَنَّهَا تَجُوزُ أَيْضًا ‏.‏ وَقَالَ أَحْمَدُ وَمَنْ صَلاَّهَا قَبْلَ الزَّوَالِ فَإِنَّهُ لَمْ يَرَ عَلَيْهِ إِعَادَةً ‏.‏\hadithno{504}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Anas, :from the Prophet, similarly}}
\hadithdefcmd{tirmidhi}{505}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ الْفَلاَّسُ الصَّيْرَفِيُّ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، وَيَحْيَى بْنُ كَثِيرٍ أَبُو غَسَّانَ الْعَنْبَرِيُّ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ الْعَلاَءِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَخْطُبُ إِلَى جِذْعٍ فَلَمَّا اتَّخَذَ النَّبِيُّ صلى الله عليه وسلم الْمِنْبَرَ حَنَّ الْجِذْعُ حَتَّى أَتَاهُ فَالْتَزَمَهُ فَسَكَنَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَجَابِرٍ وَسَهْلِ بْنِ سَعْدٍ وَأُبَىِّ بْنِ كَعْبٍ وَابْنِ عَبَّاسٍ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَمُعَاذُ بْنُ الْعَلاَءِ هُوَ بَصْرِيٌّ وَهُوَ أَخُو أَبِي عَمْرِو بْنِ الْعَلاَءِ ‏.‏\hadithno{505}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Umar narrated:"The Prophet would give the Khutbah next to the trunk of a date palm. When he [the Prophet] began using the Minbar the trunk cried out for him until he came to it and held it, so it became quiet}}
\hadithdefcmd{tirmidhi}{506}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الْبَصْرِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَخْطُبُ يَوْمَ الْجُمُعَةِ ثُمَّ يَجْلِسُ ثُمَّ يَقُومُ فَيَخْطُبُ قَالَ مِثْلَ مَا تَفْعَلُونَ الْيَوْمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَجَابِرِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي رَآهُ أَهْلُ الْعِلْمِ أَنْ يَفْصِلَ بَيْنَ الْخُطْبَتَيْنِ بِجُلُوسٍ ‏.‏\hadithno{506}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"The Prophet would give a Khutbah on Friday, then sit, then stand and give (another) Khutbah." He said: "Similar to what they do today}}
\hadithdefcmd{tirmidhi}{507}{حَدَّثَنَا قُتَيْبَةُ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنْتُ أُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم فَكَانَتْ صَلاَتُهُ قَصْدًا وَخُطْبَتُهُ قَصْدًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَمَّارِ بْنِ يَاسِرٍ وَابْنِ أَبِي أَوْفَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{507}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin Samurah narrated:"I would pray with the Prophet, and his prayer was moderate, and his Khutbah was moderate}}
\hadithdefcmd{tirmidhi}{508}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏(‏ونَادَوُا يَا مَالِكُ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ يَعْلَى بْنِ أُمَيَّةَ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ وَهُوَ حَدِيثُ ابْنِ عُيَيْنَةَ ‏.‏ وَقَدِ اخْتَارَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ يَقْرَأَ الإِمَامُ فِي الْخُطْبَةِ آيًا مِنَ الْقُرْآنِ ‏.‏ قَالَ الشَّافِعِيُّ وَإِذَا خَطَبَ الإِمَامُ فَلَمْ يَقْرَأْ فِي خُطْبَتِهِ شَيْئًا مِنَ الْقُرْآنِ أَعَادَ الْخُطْبَةَ ‏.‏\hadithno{508}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Safwan bin Ya'la bin Umayyah narrated from his father who said:"I heard the Prophet reciting, when on the Minbar: And they will cry: "O Malik (keeper of Hell)!"." [He said:] There are narrations on this topic from Abu Hurairah and Jabir bin Samurah}}
\hadithdefcmd{tirmidhi}{509}{حَدَّثَنَا عَبَّادُ بْنُ يَعْقُوبَ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ بْنِ عَطِيَّةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَوَى عَلَى الْمِنْبَرِ اسْتَقْبَلْنَاهُ بِوُجُوهِنَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَحَدِيثُ مَنْصُورٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ الْفَضْلِ بْنِ عَطِيَّةَ ‏.‏ وَمُحَمَّدُ بْنُ الْفَضْلِ بْنِ عَطِيَّةَ ضَعِيفٌ ذَاهِبُ الْحَدِيثِ عِنْدَ أَصْحَابِنَا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَسْتَحِبُّونَ اسْتِقْبَالَ الإِمَامِ إِذَا خَطَبَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ يَصِحُّ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم شَيْءٌ ‏.‏\hadithno{509}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated:"When Allah's Messenger descending the Minbar he would face our direction}}
\hadithdefcmd{tirmidhi}{510}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ جَاءَ رَجُلٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَصَلَّيْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ قُمْ فَارْكَعْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ ‏.‏\hadithno{510}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin Abdullah narrated:"The Prophet was delivering a Khutbah on Friday when a man came. The Prophet said: 'Have you prayed?' He said no. So he said: 'Then stand and pray.'" Abu Eisa said: This Hadith is Hasan Sahih [It is the most correct thing about this topic]}}
\hadithdefcmd{tirmidhi}{511}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، دَخَلَ يَوْمَ الْجُمُعَةِ وَمَرْوَانُ يَخْطُبُ فَقَامَ يُصَلِّي فَجَاءَ الْحَرَسُ لِيُجْلِسُوهُ فَأَبَى حَتَّى صَلَّى فَلَمَّا انْصَرَفَ أَتَيْنَاهُ فَقُلْنَا رَحِمَكَ اللَّهُ إِنْ كَادُوا لَيَقَعُوا بِكَ ‏.‏ فَقَالَ مَا كُنْتُ لأَتْرُكَهُمَا بَعْدَ شَيْءٍ رَأَيْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ ذَكَرَ أَنَّ رَجُلاً جَاءَ يَوْمَ الْجُمُعَةِ فِي هَيْئَةٍ بَذَّةٍ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ فَأَمَرَهُ فَصَلَّى رَكْعَتَيْنِ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ كَانَ سُفْيَانُ بْنُ عُيَيْنَةَ يُصَلِّي رَكْعَتَيْنِ إِذَا جَاءَ وَالإِمَامُ يَخْطُبُ وَكَانَ يَأْمُرُ بِهِ وَكَانَ أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ يَرَاهُ ‏.‏ قَالَ أَبُو عِيسَى وَسَمِعْتُ ابْنَ أَبِي عُمَرَ يَقُولُ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ كَانَ مُحَمَّدُ بْنُ عَجْلاَنَ ثِقَةً مَأْمُونًا فِي الْحَدِيثِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ الْخُدْرِيِّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا دَخَلَ وَالإِمَامُ يَخْطُبُ فَإِنَّهُ يَجْلِسُ وَلاَ يُصَلِّي ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا الْعَلاَءُ بْنُ خَالِدٍ الْقُرَشِيُّ قَالَ رَأَيْتُ الْحَسَنَ الْبَصْرِيَّ دَخَلَ الْمَسْجِدَ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَصَلَّى رَكْعَتَيْنِ ثُمَّ جَلَسَ ‏.‏ إِنَّمَا فَعَلَ الْحَسَنُ اتِّبَاعًا لِلْحَدِيثِ وَهُوَ رَوَى عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثَ ‏.‏\hadithno{511}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Iyad bin Abdullah bin Abi Sarh narrated:"Abu Sa'eed Al-Khudri entered (the mosque) on Friday while Marwan was giving the Khutbah, so he began praying. Two guards came to make him sit down but he refused until he had prayed. When he finished he came to us and we said: 'May Allah have mercy upon you. They nearly harmed you.' He said: 'I was not going to stop performing them (the two Rak'ah) after what I saw from Allah's Messenger.' Then he mentioned that a man who appeared untidy came on Fridy while the Prophet was delivering the Friday Khutbah, so he ordered him to pray two Rak'ah all the while the Prophet was delivering the Khutbah}}
\hadithdefcmd{tirmidhi}{512}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ أَنْصِتْ فَقَدْ لَغَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا لِلرَّجُلِ أَنْ يَتَكَلَّمَ وَالإِمَامُ يَخْطُبُ وَقَالُوا إِنْ تَكَلَّمَ غَيْرُهُ فَلاَ يُنْكِرْ عَلَيْهِ إِلاَّ بِالإِشَارَةِ ‏.‏ وَاخْتَلَفُوا فِي رَدِّ السَّلاَمِ وَتَشْمِيتِ الْعَاطِسِ وَالإِمَامُ يَخْطُبُ فَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي رَدِّ السَّلاَمِ وَتَشْمِيتِ الْعَاطِسِ وَالإِمَامُ يَخْطُبُ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَغَيْرِهِمْ ذَلِكَ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{512}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Whoever said: 'Be quiet' while the Imam is giving the Khutbah then he has committed Laghw (useless activity)}}
\hadithdefcmd{tirmidhi}{513}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَخَطَّى رِقَابَ النَّاسِ يَوْمَ الْجُمُعَةِ اتَّخَذَ جِسْرًا إِلَى جَهَنَّمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ الْجُهَنِيِّ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ بْنِ سَعْدٍ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا أَنْ يَتَخَطَّى الرَّجُلُ رِقَابَ النَّاسِ يَوْمَ الْجُمُعَةِ وَشَدَّدُوا فِي ذَلِكَ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي رِشْدِينَ بْنِ سَعْدٍ وَضَعَّفَهُ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{513}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sahl bin Ma'adh bin Anas al Jahni narrated from his father that :Allah's Messenger said: "Whoever steps over the necks of the people on Friday, he has taken a bridge to Hell}}
\hadithdefcmd{tirmidhi}{514}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، وَعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالاَ حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْحَبْوَةِ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو مَرْحُومٍ اسْمُهُ عَبْدُ الرَّحِيمِ بْنُ مَيْمُونٍ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ الْحَبْوَةَ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ وَرَخَّصَ فِي ذَلِكَ بَعْضُهُمْ مِنْهُمْ عَبْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُهُ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ لاَ يَرَيَانِ بِالْحَبْوَةِ وَالإِمَامُ يَخْطُبُ بَأْسًا ‏.‏\hadithno{514}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Ma'adh narrated from his father:"The Prophet prohibited Al-Habwah on Friday while the Imam is delivering the Khutbah}}
\hadithdefcmd{tirmidhi}{515}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، قَالَ سَمِعْتُ عُمَارَةَ بْنَ، رُوَيْبَةَ الثَّقَفِيَّ، وَبِشْرُ بْنُ مَرْوَانَ، يَخْطُبُ فَرَفَعَ يَدَيْهِ فِي الدُّعَاءِ فَقَالَ عُمَارَةُ قَبَّحَ اللَّهُ هَاتَيْنِ الْيُدَيَّتَيْنِ الْقُصَيِّرَتَيْنِ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا يَزِيدُ عَلَى أَنْ يَقُولَ هَكَذَا وَأَشَارَ هُشَيْمٌ بِالسَّبَّابَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{515}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Husain narrated:"I heard Umarah bin Rawaibah Ath-Thaqafi - while Bishr bin Marwan was delivering Khutbah and raising his hands in supplication - so Umarah said: 'May Allah disgrace these two insignificant hands, I have seen Allah's Messenger, and he would not do any more than this;'" and Hushaim (one of the narrators) motioned with his index finger}}
\hadithdefcmd{tirmidhi}{516}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ كَانَ الأَذَانُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ إِذَا خَرَجَ الإِمَامُ وَإِذَا أُقِيمَتِ الصَّلاَةُ فَلَمَّا كَانَ عُثْمَانُ رضى الله عنه زَادَ النِّدَاءَ الثَّالِثَ عَلَى الزَّوْرَاءِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{516}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{As-Sa'ib bin Yazid narrated:"The Adhan during the time of Allah's Messenger, Abu Bakr, and Umar was when the Imam came out, [and when] the Iqamah was called for the Salat. Then Uthman [may Allah be pleased with him] added a third call at Az-Zawra}}
\hadithdefcmd{tirmidhi}{517}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُكَلَّمُ بِالْحَاجَةِ إِذَا نَزَلَ عَنِ الْمِنْبَرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ جَرِيرِ بْنِ حَازِمٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ وَهِمَ جَرِيرُ بْنُ حَازِمٍ فِي هَذَا الْحَدِيثِ وَالصَّحِيحُ مَا رُوِيَ عَنْ ثَابِتٍ عَنْ أَنَسٍ قَالَ أُقِيمَتِ الصَّلاَةُ فَأَخَذَ رَجُلٌ بِيَدِ النَّبِيِّ صلى الله عليه وسلم فَمَا زَالَ يُكَلِّمُهُ حَتَّى نَعَسَ بَعْضُ الْقَوْمِ ‏.‏ قَالَ مُحَمَّدٌ وَالْحَدِيثُ هُوَ هَذَا ‏.‏ وَجَرِيرُ بْنُ حَازِمٍ رُبَّمَا يَهِمُ فِي الشَّىْءِ وَهُوَ صَدُوقٌ ‏.‏ قَالَ مُحَمَّدٌ وَهِمَ جَرِيرُ بْنُ حَازِمٍ فِي حَدِيثِ ثَابِتٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ وَيُرْوَى عَنْ حَمَّادِ بْنِ زَيْدٍ قَالَ كُنَّا عِنْدَ ثَابِتٍ الْبُنَانِيِّ فَحَدَّثَ حَجَّاجٌ الصَّوَّافُ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏ ‏.‏ فَوَهِمَ جَرِيرٌ فَظَنَّ أَنَّ ثَابِتًا حَدَّثَهُمْ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{517}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated:"Allah's Messenger would talk as necessary after descending from the Minbar}}
\hadithdefcmd{tirmidhi}{518}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ لَقَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم بَعْدَ مَا تُقَامُ الصَّلاَةُ يُكَلِّمُهُ الرَّجُلُ يَقُومُ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ فَمَا يَزَالُ يُكَلِّمُهُ فَلَقَدْ رَأَيْتُ بَعْضَنَا يَنْعَسُ مِنْ طُولِ قِيَامِ النَّبِيِّ صلى الله عليه وسلم لَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{518}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas narrated:"I saw the Prophet, after the Iqamah was called for Salat, talking to a man who was standing between him and the Qiblah, he did not stop talking, and I saw some of them getting sleepy from his lengthy standing the Prophet}}
\hadithdefcmd{tirmidhi}{519}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ اسْتَخْلَفَ مَرْوَانُ أَبَا هُرَيْرَةَ عَلَى الْمَدِينَةِ وَخَرَجَ إِلَى مَكَّةَ فَصَلَّى بِنَا أَبُو هُرَيْرَةَ يَوْمَ الْجُمُعَةِ فَقَرَأَ سُورَةَ الْجُمُعَةِ وَفِي السَّجْدَةِ الثَّانِيَةِ‏:‏ ‏(‏ِإذَا جَاءَكَ الْمُنَافِقُونَ ‏)‏ قَالَ عُبَيْدُ اللَّهِ فَأَدْرَكْتُ أَبَا هُرَيْرَةَ فَقُلْتُ لَهُ تَقْرَأُ بِسُورَتَيْنِ كَانَ عَلِيٌّ يَقْرَأُ بِهِمَا بِالْكُوفَةِ قَالَ أَبُو هُرَيْرَةَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهِمَا ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَأَبِي عِنَبَةَ الْخَوْلاَنِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقْرَأُ فِي صَلاَةِ الْجُمُعَةِ بِـ ‏(‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏)‏ وَ ‏(‏هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏)‏ ‏.‏ عُبَيْدُ اللَّهِ بْنُ أَبِي رَافِعٍ كَاتِبُ عَلِيِّ بْنِ أَبِي طَالِبٍ رَضِيَ اللَّهُ عَنْهُ ‏.‏\hadithno{519}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ubaidullah bin Abi Rafi the freed slave of Allah's Messenger said:"Marwan left Abu Hurairah in charge of Al-Madinah and he went to Makkah. So Abu Hurairah led us in Salat in Friday, reciting Surah Al-Jumuah (in the first Rak'ah) and in the second prostration (Rak'ah): When the hypocrites come to you." Ubaidullah said: "So I caught up with Abu Hurairah and said to him: 'You recited two Surah that Ali recited in Al-Kufah. Abu Hurairah said: 'Indeed I heard Allah's Messenger reciting them}}
\hadithdefcmd{tirmidhi}{520}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ مُخَوَّلِ بْنِ رَاشِدٍ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ يَوْمَ الْجُمُعَةِ فِي صَلاَةِ الْفَجْرِ * ‏(‏تَنْزِيلُ ‏)‏ السَّجْدَةَ وَ ‏(‏هَلْ أَتَى عَلَى الإِنْسَانِ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَشُعْبَةُ وَغَيْرُ وَاحِدٍ عَنْ مُخَوَّلٍ ‏.‏\hadithno{520}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"For the Fajr prayer on Friday, Allah's Messenger would recite: Alif Lam Mem (which is) revealed in (Surat) As-Sajdah and, Has there not been over man}}
\hadithdefcmd{tirmidhi}{521}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَيْضًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ ‏.‏\hadithno{521}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated from his father:"The Prophet would pray two Rak;ah after the Friday prayer}}
\hadithdefcmd{tirmidhi}{522}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا صَلَّى الْجُمُعَةَ انْصَرَفَ فَصَلَّى سَجْدَتَيْنِ فِي بَيْتِهِ ثُمَّ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{522}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Nafi narrated about Ibn Umar:"When he prayed the Friday prayer, he left and prayed two prostrations (Rak'ah) in his house. Then he said: 'Allah's Messenger would do this}}
\hadithdefcmd{tirmidhi}{523}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مِنْكُمْ مُصَلِّيًا بَعْدَ الْجُمُعَةِ فَلْيُصَلِّ أَرْبَعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ حَدَّثَنَا عَلِيُّ بْنُ الْمَدِينِيِّ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ قَالَ كُنَّا نَعُدُّ سُهَيْلَ بْنَ أَبِي صَالِحٍ ثَبْتًا فِي الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ أَنَّهُ كَانَ يُصَلِّي قَبْلَ الْجُمُعَةِ أَرْبَعًا وَبَعْدَهَا أَرْبَعًا ‏.‏ وَقَدْ رُوِيَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ رضى الله عنه أَنَّهُ أَمَرَ أَنْ يُصَلَّى بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ ثُمَّ أَرْبَعًا ‏.‏ وَذَهَبَ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ إِلَى قَوْلِ ابْنِ مَسْعُودٍ ‏.‏ وَقَالَ إِسْحَاقُ إِنْ صَلَّى فِي الْمَسْجِدِ يَوْمَ الْجُمُعَةِ صَلَّى أَرْبَعًا وَإِنْ صَلَّى فِي بَيْتِهِ صَلَّى رَكْعَتَيْنِ ‏.‏ وَاحْتَجَّ بِأَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ فِي بَيْتِهِ وَحَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ مِنْكُمْ مُصَلِّيًا بَعْدَ الْجُمُعَةِ فَلْيُصَلِّ أَرْبَعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَابْنُ عُمَرَ هُوَ الَّذِي رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ فِي بَيْتِهِ وَابْنُ عُمَرَ بَعْدَ النَّبِيِّ صلى الله عليه وسلم صَلَّى فِي الْمَسْجِدِ بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ وَصَلَّى بَعْدَ الرَّكْعَتَيْنِ أَرْبَعًا ‏.‏ حَدَّثَنَا بِذَلِكَ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ رَأَيْتُ ابْنَ عُمَرَ صَلَّى بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ ثُمَّ صَلَّى بَعْدَ ذَلِكَ أَرْبَعًا ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ عَمْرِو بْنِ دِينَارٍ قَالَ مَا رَأَيْتُ أَحَدًا أَنَصَّ لِلْحَدِيثِ مِنَ الزُّهْرِيِّ وَمَا رَأَيْتُ أَحَدًا الدَّنَانِيرُ وَالدَّرَاهِمُ أَهْوَنُ عَلَيْهِ مِنْهُ إِنْ كَانَتِ الدَّنَانِيرُ وَالدَّرَاهِمُ عِنْدَهُ بِمَنْزِلَةِ الْبَعْرِ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْت ابْنَ أَبِي عُمَرَ قَال سَمِعْتُ سُفْيَانَ بْنَ عُيَيْنَةَ يَقُولُ كَانَ عَمْرُو بْنُ دِينَارٍ أَسَنَّ مِنْ الزُّهْرِيِّ\hadithno{523}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Whoever among you is to pray after the Friday prayer, then let him pray four}}
\hadithdefcmd{tirmidhi}{524}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا مَنْ أَدْرَكَ رَكْعَةً مِنَ الْجُمُعَةِ صَلَّى إِلَيْهَا أُخْرَى وَمَنْ أَدْرَكَهُمْ جُلُوسًا صَلَّى أَرْبَعًا ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{524}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Whoever catches a Rak'ah of the Salat then he has caught the Salat}}
\hadithdefcmd{tirmidhi}{525}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، رضى الله عنه قَالَ مَا كُنَّا نَتَغَدَّى فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ نَقِيلُ إِلاَّ بَعْدَ الْجُمُعَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ رضى الله عنه ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَهْلِ بْنِ سَعْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{525}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sahl bin Sa'd narrated:"We would not have lunch during the time of Allah's Messenger, nor would we have a siesta, until after the Friday prayer}}
\hadithdefcmd{tirmidhi}{526}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَأَبُو خَالِدٍ الأَحْمَرُ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ فَلْيَتَحَوَّلْ مِنْ مَجْلِسِهِ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{526}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated that :the Prophet said: "When one of you becomes sleepy during the Friday prayer, then let him move from where he is sitting}}
\hadithdefcmd{tirmidhi}{527}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْحَجَّاجِ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم عَبْدَ اللَّهِ بْنَ رَوَاحَةَ فِي سَرِيَّةٍ فَوَافَقَ ذَلِكَ يَوْمَ الْجُمُعَةِ فَغَدَا أَصْحَابُهُ فَقَالَ أَتَخَلَّفُ فَأُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ أَلْحَقُهُمْ ‏.‏ فَلَمَّا صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم رَآهُ فَقَالَ ‏"‏ مَا مَنَعَكَ أَنْ تَغْدُوَ مَعَ أَصْحَابِكَ ‏"‏ ‏.‏ فَقَالَ أَرَدْتُ أَنْ أُصَلِّيَ مَعَكَ ثُمَّ أَلْحَقَهُمْ ‏.‏ قَالَ ‏"‏ لَوْ أَنْفَقْتَ مَا فِي الأَرْضِ جَمِيعًا مَا أَدْرَكْتَ فَضْلَ غَدْوَتِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ قَالَ شُعْبَةُ لَمْ يَسْمَعِ الْحَكَمُ مِنْ مِقْسَمٍ إِلاَّ خَمْسَةَ أَحَادِيثَ ‏.‏ وَعَدَّهَا شُعْبَةُ وَلَيْسَ هَذَا الْحَدِيثُ فِيمَا عَدَّ شُعْبَةُ فَكَأَنَّ هَذَا الْحَدِيثَ لَمْ يَسْمَعْهُ الْحَكَمُ مِنْ مِقْسَمٍ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي السَّفَرِ يَوْمَ الْجُمُعَةِ فَلَمْ يَرَ بَعْضُهُمْ بَأْسًا بِأَنْ يَخْرُجَ يَوْمَ الْجُمُعَةِ فِي السَّفَرِ مَا لَمْ تَحْضُرِ الصَّلاَةُ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا أَصْبَحَ فَلاَ يَخْرُجْ حَتَّى يُصَلِّيَ الْجُمُعَةَ ‏.‏\hadithno{527}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet sent Abdullah bin Rawahah to lead a military detachment, and that corresponded to a Friday. So his companions left early in the day, and he said: 'I will remain behind to pray with Allah's Messenger then meet up with them.' When he prayed with the Prophet, he saw him and said: 'What prevented you from leaving earlier with your companions?' He said: 'I wanted to pray with you then meet up with them.' He said: 'If you have spent [all of] what is in the earth, you would not have achieved the virtue you have had you left early in the day with them}}
\hadithdefcmd{tirmidhi}{528}{حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ الْكُوفِيُّ، حَدَّثَنَا أَبُو يَحْيَى، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَقٌّ عَلَى الْمُسْلِمِينَ أَنْ يَغْتَسِلُوا يَوْمَ الْجُمُعَةِ وَلْيَمَسَّ أَحَدُهُمْ مِنْ طِيبِ أَهْلِهِ فَإِنْ لَمْ يَجِدْ فَالْمَاءُ لَهُ طِيبٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَشَيْخٍ مِنَ الأَنْصَارِ ‏.‏\hadithno{528}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Bara bin Azib narrated that :Allah's Messenger said: "It is a duty for the Muslims, that they perform Ghusl on Friday, and that each of them wear some of his family's perfume. If he does not find any, then water is a perfume for him}}
\hadithdefcmd{tirmidhi}{529}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ حَسَنٌ ‏.‏ وَرِوَايَةُ هُشَيْمٍ أَحْسَنُ مِنْ رِوَايَةِ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ ‏.‏ وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ أَبْوَابُ الْعِيدَيْنِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{529}\hadithgrade{Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Bara bin Azib narrated:(Another route for the same chain) similar in meaning}}
